@@ -2,12 +2,16 @@ enc_in = {
 		"&01": "<",
 		"&02": " ",
 		"&03": "=",
+		"&04": "\n",
+		"&05": "\t"
 	}
 
 enc_out = {
 	"<": "&01",
 	" ": "&02",
-	"=": "&03"
+	"=": "&03",
+	"\n": "&04",
+	"\t": "&05"
 }
 
 def create_node(node: dict):
