@@ -13,8 +13,7 @@ class xml(object):
 	xml(path: str) -> xml
 
 	With this class you can read an XML file and update it with a simple, object-like interface.
-	When used in e.g. 'print' function, returns it's list with all XML nodes.
-	When called, returns it's representation of an XML file.
+	When used in 'str()', returns (updated in real time) XML file code.
 	"""
 	def __init__(self: object, path: str) -> object:
 		self.path = path
@@ -93,9 +92,6 @@ class xml(object):
 				break
 
 	def __str__(self: object) -> object:
-		return str(self.__list)
-
-	def __call__(self: object) -> str:
 		nodes = ""
 
 		for node in self.__list:
