@@ -16,16 +16,12 @@ class xml_node(object):
 
 	Used to manage single XML nodes.
 	Should be used only by 'xml' class and self objects.
-	When used in e.g. 'print' function, returns it's dict.
-	When called, returns it's representation of real XML node.
+	When used in 'str()', returns XML node based on itself.
 	"""
 	def __init__(self: object, node: dict) -> object:
 		self.__node = node
 
 	def __str__(self: object) -> object:
-		return str(self.__node)
-
-	def __call__(self: object) -> str:
 		return create_node(self.__node)
 
 	def get_name(self: object) -> str:
